DataLad extension template
**************************

This is a template for creating a `DataLad <http://datalad.org>`__ extension
that equips DataLad with additional functionality.


API
===

High-level API commands
-----------------------

.. currentmodule:: datalad.api
.. autosummary::
   :toctree: generated

   credentials


Command line reference
----------------------

.. toctree::
   :maxdepth: 1

   generated/man/datalad-credentials


Python utilities
----------------

.. currentmodule:: datalad_next
.. autosummary::
   :toctree: generated

   credman


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
